@@ -19,7 +19,7 @@ setMethod("ros", signature(obs="numeric", censored="logical"),
           function(obs, censored, forwardT = "log", reverseT = "exp")
 {
     if (is.null(forwardT) || is.null(reverseT)) {
-        forwardT = reverseT = ".trueT"
+        forwardT = reverseT = "trueT"
     }
     else if (!exists(forwardT)) {
          stop("Can not find Forward Transformation function: ", forwardT, "\n")
@@ -66,9 +66,9 @@ lros = ros
 # names like cen*
 cenros = ros
 
-#  .trueT is provided so that ros() can be used with no transforms.
+#  trueT is provided so that ros() can be used with no transforms.
 #  (It is a quick hack -- rather than recoding ros and family)
-.trueT =
+trueT =
 function(x)
 {
     return(x)
@@ -76,23 +76,17 @@ function(x)
 
 setMethod("print", signature(x="ros"), function(x, ...)
 {
-    cat("\nMultiply-Censored ROS Model\n\n")
+    n       = length(x$modeled)
+    n.cen   = length(x$modeled[x$censored])
+    median  = median(x)
+    mean    = mean(x)
+    sd      = sd(x)
 
-    uncen.n = length(x$modeled[!x$censored])
-    cen.n   = length(x$modeled[x$censored])
+    ret = c(n, n.cen, median, mean, sd)
+    names(ret) = c("n", "n.cen", "median", "mean", "sd")
 
-    cat("           N:", (uncen.n + cen.n), "\n")
-    cat("    Censored:", cen.n, "\n")
-    cat("  % Censored:", format((cen.n/(cen.n+uncen.n))*100, digits=4), "\n")
-    cat("\n");
-    
-    cat("        Mean:", format(mean(x), digits=4), "\n")
-    cat("      StdDev:", format(sd(x), digits=4), "\n")
-    cat("\n");
-    cat("   Quantiles:\n")
-    print(quantile(x))
-    cat("\n");
-    cat("Use summary() to view the linear regression model\n\n")
+    print(ret)
+    invisible(ret)
 })
 
 setMethod("summary", "ros", function(object, plot=FALSE, ...)
@@ -123,6 +117,20 @@ setMethod("sd", signature(x="ros"), function(x, na.rm=FALSE)
 
 setMethod("median", "ros", function(x, na.rm=FALSE) median(x$modeled))
 
+
+### min and max methods don't work yet cuz I don't know how to eval
+##  the expanded dots correctly yet.
+#setMethod("min", "ros", function(..., na.rm=FALSE) 
+#{
+#    x = match.call(expand.dots=TRUE)[[2]]
+#    min(eval.parent(x$modeled))
+#})
+#setMethod("max", "ros", function(..., na.rm=FALSE) 
+#{
+#    x = match.call(expand.dots=TRUE)[[2]]
+#    max(eval.parent(x$modeled))
+#})
+
 ## Query and prediction functions for ROS objects
 
 setMethod("quantile", signature(x="ros"), function(x, probs=NADAprobs,...)
@@ -148,6 +156,13 @@ setMethod("lines", signature(x="ros"), function (x, ...)
     lines(x=minmax.nq, y=predict(x, minmax.nq), ...)
 })
 
+## Broken for the time being -- use lines
+#setMethod("abline", signature(a="ros"), 
+#          function(a, b, h, v, reg, coef, untf, col, lty, lwd, ...) 
+#{
+#    minmax.nq = qnorm(c(min(a$pp), max(a$pp)))
+#    lines(x=minmax.nq, y=predict(a, minmax.nq), ...)
+#})
 
 # Constructs a prob-plot representation of a ROS model
 setMethod("plot", signature(x="ros", y="missing"),
@@ -224,6 +239,19 @@ setMethod("plot", signature(x="ros", y="missing"),
       }
 })
 
+setMethod("boxplot", signature(x="ros"), function(x, log="y", range=0,...)
+{
+    # use boxplot.default instead
+    bx = boxplot(x$modeled, plot=FALSE, range=range, ...)
+
+    # The vector stats is the famous five -- with outlier limts.
+    # We relpace the quantiles with the ros-modeled ones
+    bx$stats[2:4] = as.vector(quantile(x, c(0.25, 0.5, 0.75)))
+    bx$stats = as.matrix(bx$stats)
+
+    bxp(bx, log=log, ...)
+    invisible(bx)
+})
 
 ## Routines for calculating Helsel-Cohn style plotting positions
 
@@ -244,10 +272,7 @@ function(obs, censored)
     if (!any(censored)) pp = ppoints(obs)
     else
       {
-        uncen = obs[!censored]
-        cen   = obs[censored]
-
-        cn = .cohnN(uncen, cen)
+        cn = cohn(obs, censored)
         pp[!censored] = hc.ppoints.uncen(cn=cn)
         pp[censored]  = hc.ppoints.cen(cn=cn)
       }
@@ -255,13 +280,20 @@ function(obs, censored)
     return(pp)
 }
 
-# .cohnN Calculates 'Cohn' numbers -- quantities described by 
+# cohn Calculates "Cohn" Numbers -- quantities described by 
 # Helsel and Cohn's (1988) reformulation of a prob-plotting formula
 # described by Hirsch and Stedinger (1987).
-.cohnN =
-function(uncen, cen)
+# The Cohn Numbers are:
+# A_j   = the number of uncensored obs above the jth threshold.
+# B_j   = the number of observations (cen & uncen) below the lowest threshold.
+# C_j   = the number of censored observations between j and j-1
+# P_j   = the probability of exceeding the jth threshold
+cohn =
+function(obs, censored)
 {
-    alldata = c(uncen, cen)
+    uncen = obs[!censored]
+    cen   = obs[censored]
+
     A = B = C = P = numeric()
 
     limit = sort(unique(cen))
@@ -272,7 +304,7 @@ function(uncen, cen)
     i = length(limit)
 
     A[i] = length(uncen[ uncen >= limit[i] ])
-    B[i] = length(alldata[alldata <= limit[i]])
+    B[i] = length(obs[obs <= limit[i]])
     C[i] = length(cen[ cen == limit[i] ])
     P[i] = A[i]/(A[i] + B[i])
 
@@ -280,12 +312,13 @@ function(uncen, cen)
     while (i > 0)
       {
         A[i] = length(uncen[ uncen >= limit[i] & uncen < limit[i + 1] ])
-        B[i] = length(alldata[alldata <= limit[i]])
-        C[i] = length(cen[ cen == limit[i] ])
+        B[i] = length(obs[obs <= limit[i]])
+        C[i] = length(cen[cen == limit[i]])
         P[i] = P[i + 1] + ((A[i]/(A[i] + B[i])) * (1 - P[i + 1]))
 
         i = i - 1
       }
+
     return(list(A=A, B=B, C=C, P=P, limit=limit))
 }
 
@@ -293,7 +326,7 @@ function(uncen, cen)
 hc.ppoints.uncen =
 function(obs, censored, cn)
 {
-    if (missing(cn)) { cn = .cohnN(obs, censored) }
+    if (missing(cn)) { cn = cohn(obs, censored) }
 
     nonzero = (cn$A != 0)
     A     = cn$A[nonzero]
@@ -322,7 +355,7 @@ function(obs, censored, cn)
 hc.ppoints.cen =
 function(obs, censored, cn)
 {    
-    if (missing(cn)) { cn = .cohnN(obs, censored) }
+    if (missing(cn)) { cn = cohn(obs, censored) }
 
     C     = cn$C
     P     = cn$P
